# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.13
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CertSigningReqStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'certificates': 'list[X509Certificate]',
        'common_name': 'str',
        'dns_names': 'list[str]'
    }

    attribute_map = {
        'certificates': 'certificates',
        'common_name': 'common_name',
        'dns_names': 'dns_names'
    }

    def __init__(self, certificates=None, common_name=None, dns_names=None, local_vars_configuration=None):  # noqa: E501
        """CertSigningReqStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._certificates = None
        self._common_name = None
        self._dns_names = None
        self.discriminator = None

        if certificates is not None:
            self.certificates = certificates
        if common_name is not None:
            self.common_name = common_name
        if dns_names is not None:
            self.dns_names = dns_names

    @property
    def certificates(self):
        """Gets the certificates of this CertSigningReqStatus.  # noqa: E501

        The issued x509 certificates, formatted as PEM. This list is sorted by X509Certificate.not_before.   # noqa: E501

        :return: The certificates of this CertSigningReqStatus.  # noqa: E501
        :rtype: list[X509Certificate]
        """
        return self._certificates

    @certificates.setter
    def certificates(self, certificates):
        """Sets the certificates of this CertSigningReqStatus.

        The issued x509 certificates, formatted as PEM. This list is sorted by X509Certificate.not_before.   # noqa: E501

        :param certificates: The certificates of this CertSigningReqStatus.  # noqa: E501
        :type: list[X509Certificate]
        """

        self._certificates = certificates

    @property
    def common_name(self):
        """Gets the common_name of this CertSigningReqStatus.  # noqa: E501

        The certificate common name (CN)   # noqa: E501

        :return: The common_name of this CertSigningReqStatus.  # noqa: E501
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """Sets the common_name of this CertSigningReqStatus.

        The certificate common name (CN)   # noqa: E501

        :param common_name: The common_name of this CertSigningReqStatus.  # noqa: E501
        :type: str
        """

        self._common_name = common_name

    @property
    def dns_names(self):
        """Gets the dns_names of this CertSigningReqStatus.  # noqa: E501

        The list of domains of which the CSR is requesting to be issued to.  # noqa: E501

        :return: The dns_names of this CertSigningReqStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._dns_names

    @dns_names.setter
    def dns_names(self, dns_names):
        """Sets the dns_names of this CertSigningReqStatus.

        The list of domains of which the CSR is requesting to be issued to.  # noqa: E501

        :param dns_names: The dns_names of this CertSigningReqStatus.  # noqa: E501
        :type: list[str]
        """

        self._dns_names = dns_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertSigningReqStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertSigningReqStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.13
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Catalogue(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'category': 'str',
        'catalogue_entries': 'list[CatalogueEntry]',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'category': 'category',
        'catalogue_entries': 'catalogue_entries',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, category=None, catalogue_entries=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """Catalogue - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._category = None
        self._catalogue_entries = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if category is not None:
            self.category = category
        if catalogue_entries is not None:
            self.catalogue_entries = catalogue_entries
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        """Gets the id of this Catalogue.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this Catalogue.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Catalogue.

        Unique identifier  # noqa: E501

        :param id: The id of this Catalogue.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def category(self):
        """Gets the category of this Catalogue.  # noqa: E501

        The category of catalogue that this catalogue belongs to.  # noqa: E501

        :return: The category of this Catalogue.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Catalogue.

        The category of catalogue that this catalogue belongs to.  # noqa: E501

        :param category: The category of this Catalogue.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                category is not None and len(category) > 100):
            raise ValueError("Invalid value for `category`, length must be less than or equal to `100`")  # noqa: E501

        self._category = category

    @property
    def catalogue_entries(self):
        """Gets the catalogue_entries of this Catalogue.  # noqa: E501

        The list of catalogue entries for the catalogue  # noqa: E501

        :return: The catalogue_entries of this Catalogue.  # noqa: E501
        :rtype: list[CatalogueEntry]
        """
        return self._catalogue_entries

    @catalogue_entries.setter
    def catalogue_entries(self, catalogue_entries):
        """Sets the catalogue_entries of this Catalogue.

        The list of catalogue entries for the catalogue  # noqa: E501

        :param catalogue_entries: The catalogue_entries of this Catalogue.  # noqa: E501
        :type: list[CatalogueEntry]
        """

        self._catalogue_entries = catalogue_entries

    @property
    def created(self):
        """Gets the created of this Catalogue.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this Catalogue.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Catalogue.

        Creation time  # noqa: E501

        :param created: The created of this Catalogue.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this Catalogue.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this Catalogue.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Catalogue.

        Update time  # noqa: E501

        :param updated: The updated of this Catalogue.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Catalogue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Catalogue):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.13
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class SessionsSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'revoked': 'bool',
        'number_of_logins': 'int',
        'number_of_failed_multi_factor_challenges': 'int'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'revoked': 'revoked',
        'number_of_logins': 'number_of_logins',
        'number_of_failed_multi_factor_challenges': 'number_of_failed_multi_factor_challenges'
    }

    def __init__(self, user_id=None, org_id=None, revoked=None, number_of_logins=None, number_of_failed_multi_factor_challenges=None, local_vars_configuration=None):  # noqa: E501
        """SessionsSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._revoked = None
        self._number_of_logins = None
        self._number_of_failed_multi_factor_challenges = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        if revoked is not None:
            self.revoked = revoked
        if number_of_logins is not None:
            self.number_of_logins = number_of_logins
        if number_of_failed_multi_factor_challenges is not None:
            self.number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges

    @property
    def user_id(self):
        """Gets the user_id of this SessionsSpec.  # noqa: E501

        The user id associated with the session  # noqa: E501

        :return: The user_id of this SessionsSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SessionsSpec.

        The user id associated with the session  # noqa: E501

        :param user_id: The user_id of this SessionsSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this SessionsSpec.  # noqa: E501

        The org id associated with the issuer the user is logging into  # noqa: E501

        :return: The org_id of this SessionsSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this SessionsSpec.

        The org id associated with the issuer the user is logging into  # noqa: E501

        :param org_id: The org_id of this SessionsSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def revoked(self):
        """Gets the revoked of this SessionsSpec.  # noqa: E501

        The status of a the session. A session is no longer valid if it has been revoked.  # noqa: E501

        :return: The revoked of this SessionsSpec.  # noqa: E501
        :rtype: bool
        """
        return self._revoked

    @revoked.setter
    def revoked(self, revoked):
        """Sets the revoked of this SessionsSpec.

        The status of a the session. A session is no longer valid if it has been revoked.  # noqa: E501

        :param revoked: The revoked of this SessionsSpec.  # noqa: E501
        :type: bool
        """

        self._revoked = revoked

    @property
    def number_of_logins(self):
        """Gets the number_of_logins of this SessionsSpec.  # noqa: E501

        The number of times a user has logged in during this session  # noqa: E501

        :return: The number_of_logins of this SessionsSpec.  # noqa: E501
        :rtype: int
        """
        return self._number_of_logins

    @number_of_logins.setter
    def number_of_logins(self, number_of_logins):
        """Sets the number_of_logins of this SessionsSpec.

        The number of times a user has logged in during this session  # noqa: E501

        :param number_of_logins: The number_of_logins of this SessionsSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_of_logins is not None and number_of_logins < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_logins`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_logins = number_of_logins

    @property
    def number_of_failed_multi_factor_challenges(self):
        """Gets the number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501

        The number of times a user has failed a multi-factor authentication challenge associated with this session  # noqa: E501

        :return: The number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501
        :rtype: int
        """
        return self._number_of_failed_multi_factor_challenges

    @number_of_failed_multi_factor_challenges.setter
    def number_of_failed_multi_factor_challenges(self, number_of_failed_multi_factor_challenges):
        """Sets the number_of_failed_multi_factor_challenges of this SessionsSpec.

        The number of times a user has failed a multi-factor authentication challenge associated with this session  # noqa: E501

        :param number_of_failed_multi_factor_challenges: The number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_of_failed_multi_factor_challenges is not None and number_of_failed_multi_factor_challenges < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_failed_multi_factor_challenges`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionsSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SessionsSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.13
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_message_endpoints_response import ListMessageEndpointsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListMessageEndpointsResponse(unittest.TestCase):
    """ListMessageEndpointsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListMessageEndpointsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_message_endpoints_response.ListMessageEndpointsResponse()  # noqa: E501
        if include_optional :
            return ListMessageEndpointsResponse(
                messages = [
                    agilicus_api.models.message_endpoint.MessageEndpoint(
                        metadata = agilicus_api.models.message_endpoint_metadata.MessageEndpointMetadata(
                            message_endpoint_id = '123', 
                            user_id = '123', 
                            created = '2015-07-07T15:49:51.230+02:00', 
                            updated = '2015-07-07T15:49:51.230+02:00', ), 
                        spec = agilicus_api.models.message_endpoint_spec.MessageEndpointSpec(
                            endpoint_type = 'web_push', 
                            nickname = '0', 
                            address = '0', 
                            enabled = True, ), )
                    ], 
                limit = 56
            )
        else :
            return ListMessageEndpointsResponse(
                limit = 56,
        )

    def testListMessageEndpointsResponse(self):
        """Test ListMessageEndpointsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
